==> qtjambi-nfc-5.15.13-sources.jar: io/qt/nfc/QNearFieldShareTarget.java <==
package io.qt.nfc;


/**
 * <p>Transfers data to remote device over NFC</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html">QNearFieldShareTarget</a></p>
 */
public final class QNearFieldShareTarget extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QNearFieldShareTarget.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#error">QNearFieldShareTarget::error(QNearFieldShareManager::ShareError)</a></p>
     */
    public final Signal1<io.qt.nfc.QNearFieldShareManager.ShareError> error = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#shareFinished">QNearFieldShareTarget::shareFinished()</a></p>
     */
    public final Signal0 shareFinished = new Signal0();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#cancel">QNearFieldShareTarget::cancel()</a></p>
     */
    @io.qt.QtUninvokable
    public final void cancel(){
        cancel_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void cancel_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#isShareInProgress">QNearFieldShareTarget::isShareInProgress()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean isShareInProgress(){
        return isShareInProgress_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isShareInProgress_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#share-1">QNearFieldShareTarget::share(QList&lt;QFileInfo&gt;)</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean share(java.util.Collection<? extends io.qt.core.QFileInfo> files){
        return share_native_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), files);
    }
    
    @io.qt.QtUninvokable
    private native boolean share_native_cref_QList(long __this__nativeId, java.util.Collection<? extends io.qt.core.QFileInfo> files);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#share">QNearFieldShareTarget::share(QNdefMessage)</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean share(io.qt.nfc.QNdefMessage message){
        return share_native_cref_QNdefMessage(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(message));
    }
    
    @io.qt.QtUninvokable
    private native boolean share_native_cref_QNdefMessage(long __this__nativeId, long message);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#shareError">QNearFieldShareTarget::shareError()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.nfc.QNearFieldShareManager.ShareError shareError(){
        return io.qt.nfc.QNearFieldShareManager.ShareError.resolve(shareError_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int shareError_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#shareModes">QNearFieldShareTarget::shareModes()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.nfc.QNearFieldShareManager.ShareModes shareModes(){
        return new io.qt.nfc.QNearFieldShareManager.ShareModes(shareModes_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int shareModes_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QNearFieldShareTarget(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-nfc-5.15.14-sources.jar: io/qt/nfc/QNearFieldShareTarget.java <==
package io.qt.nfc;

import io.qt.*;


/**
 * <p>Transfers data to remote device over NFC</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html">QNearFieldShareTarget</a></p>
 */
public final class QNearFieldShareTarget extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QNearFieldShareTarget.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#error">QNearFieldShareTarget::error(QNearFieldShareManager::ShareError)</a></p>
     */
    public final @NonNull Signal1<io.qt.nfc.QNearFieldShareManager.@NonNull ShareError> error = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#shareFinished">QNearFieldShareTarget::shareFinished()</a></p>
     */
    public final @NonNull Signal0 shareFinished = new Signal0();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#cancel">QNearFieldShareTarget::cancel()</a></p>
     */
    @QtUninvokable
    public final void cancel(){
        cancel_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void cancel_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#isShareInProgress">QNearFieldShareTarget::isShareInProgress()const</a></p>
     */
    @QtUninvokable
    public final boolean isShareInProgress(){
        return isShareInProgress_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isShareInProgress_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#share-1">QNearFieldShareTarget::share(QList&lt;QFileInfo&gt;)</a></p>
     */
    @QtUninvokable
    public final boolean share(java.util.@NonNull Collection<? extends io.qt.core.@NonNull QFileInfo> files){
        return share_native_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), files);
    }
    
    @QtUninvokable
    private native boolean share_native_cref_QList(long __this__nativeId, java.util.Collection<? extends io.qt.core.QFileInfo> files);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#share">QNearFieldShareTarget::share(QNdefMessage)</a></p>
     */
    @QtUninvokable
    public final boolean share(io.qt.nfc.@NonNull QNdefMessage message){
        return share_native_cref_QNdefMessage(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(message));
    }
    
    @QtUninvokable
    private native boolean share_native_cref_QNdefMessage(long __this__nativeId, long message);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#shareError">QNearFieldShareTarget::shareError()const</a></p>
     */
    @QtUninvokable
    public final io.qt.nfc.QNearFieldShareManager.@NonNull ShareError shareError(){
        return io.qt.nfc.QNearFieldShareManager.ShareError.resolve(shareError_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @QtUninvokable
    private native int shareError_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#shareModes">QNearFieldShareTarget::shareModes()const</a></p>
     */
    @QtUninvokable
    public final io.qt.nfc.QNearFieldShareManager.@NonNull ShareModes shareModes(){
        return new io.qt.nfc.QNearFieldShareManager.ShareModes(shareModes_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @QtUninvokable
    private native int shareModes_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QNearFieldShareTarget(QPrivateConstructor p) { super(p); } 
    
}
